Package 2048 - Projet informatique de 1er semestre ENSAE
========================================================

Ce module propose une fonction pour résoudre le 2048.
La fonction adeterminer(n,..) résout le 2048 n fois en utilisant la stratégie du snake.
Par exemple, si c=100, l'algorithme sera relativement rapide mais peu efficace.

Quelques détails sur la stratégie :

Blablabla

Quelques détails sur les tests :

Blablabla


Ce module peut être installé avec pip:

    pip install pack2048

Exemple d'usage:

    >>> from pack2048 import adeterminer
    >>> Evaluer(10,...)

Ce code est sous licence GNU AGPLv3.